#
# spec file for package xinetd
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xinetd
Version:        2.3.15
Release:        10.3
Url:            http://www.xinetd.org/
Summary:        An 'inetd' with Expanded Functionality
License:        xinetd
Group:          Productivity/Networking/System
Source0:        http://www.xinetd.org/%{name}-%{version}.tar.gz
Source1:        xinetd.service
Source2:        FAQ
Source3:        README.SUSE
Source4:        %{name}-service_files.tar.bz2
Source5:        logrotate
Patch0:         %{name}-2.3.14-man.dif
Patch4:         %{name}-2.3.14-server_args-fix.diff
Patch5:         %{name}-2.3.14-strict-aliasing-fix.diff
Patch6:         %{name}-2.3.14-nodeadlock.diff
Patch8:         %{name}-2.3.14-pie.patch
Patch9:         %{name}-2.3.14-ipv6-ipv4-fallback.patch
Patch10:        %{name}-2.3.14-honour_disable.patch
Patch11:        %{name}-2.3.14-ident-bind.patch
Patch12:        %{name}-2.3.14-nodeadlock-revisited.patch
#PATCH-FIX-SUSE: merge the SUSE's default xinetd.conf with upstream one
Patch13:        xinetd-config.patch
Patch15:        xinetd-CVE-2013-4342.patch
Patch16:        xinetd-2.3.14-file-limit.patch
Patch17:        xinetd-2.3.14-restore-nofile-limits.patch
Patch18:        xinetd-deactivating-error.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  autoconf
BuildRequires:  systemd
BuildRequires:  tcpd-devel
%{systemd_requires}
Provides:       inet-daemon

%description
xinetd takes the abilities of inetd and appends additional
functionality:

- Access Control
- Prevention of 'denial of access' attacks
- Extensive logging abilities
- Clear configuration file


%prep
%setup -b 0 -T -D -a 4
%patch0
%patch4
%patch5
%patch6
%patch8
%patch9
%patch10
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1

# FAQ, README.SUSE and logrotate
cp %{SOURCE2} %{SOURCE3} %{SOURCE5} .

%build
autoconf
export CFLAGS="$RPM_OPT_FLAGS -Wformat=2"
./configure \
    --prefix=%{_prefix} \
    --sysconfdir=%{_sysconfdir} \
    --mandir=%{_mandir}\
    --with-loadavg \
    --with-libwrap

make %{?_smp_mflags}

%install
install -d -m 755 %{buildroot}%{_mandir}
make install DAEMONDIR=%{buildroot}%{_sbindir} MANDIR=${RPM_BUILD_ROOT}/%{_mandir}

#config file and initial services
install -d -m 0755 %{buildroot}%{_sysconfdir}
install -m 644 contrib/%{name}.conf %{buildroot}%{_sysconfdir}/%{name}.conf
cp -a etc %{buildroot}

#xinetd.service
install -d -m 0755 %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}.service
ln -sf ../../sbin/service %{buildroot}%{_sbindir}/rc%{name}

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
if [ -x /etc/init.d/%{name} ]; then
%stop_on_removal xinetd
fi
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%doc README CHANGELOG COPYRIGHT FAQ README.SUSE logrotate
%doc %{_mandir}/man5/%{name}.conf.*
%doc %{_mandir}/man8/*
%config(noreplace) %{_sysconfdir}/xinetd.d/*
%config(noreplace) %{_sysconfdir}/%{name}.conf
%{_sbindir}/*
%{_unitdir}/%{name}.service

%changelog
* Fri Aug 29 2014 fcrozat@suse.com
- Update license tag to use SPDX 1.2.
* Sat Jun 14 2014 tchvatal@suse.com
- Drop xinetd.conf not used in spec and we use upstream one anyway.
* Fri Jun 13 2014 tchvatal@suse.com
- Revert the syslog target as it is obsolete.
* Fri Jun 13 2014 tchvatal@suse.com
- Fix error in logs when disabling service and reloading; bnc#870904
  * xinetd-deactivating-error.patch
* Wed Jun 11 2014 tchvatal@suse.com
- Wait for the syslog target too.
* Mon Mar 31 2014 vcizek@suse.com
- Add support for setting maximum number of open files (bnc#855685)
  * added xinetd-2.3.14-file-limit.patch
  * added xinetd-2.3.14-restore-nofile-limits.patch
- fixes for security vulnerabilities
  * CVE-2013-4342 (bnc#844230)
  - xinetd ignores user and group directives for tcpmux services
  - added xinetd-CVE-2013-4342.patch
* Mon Mar 17 2014 mt@suse.de
- Also removed obsolete syslog.target from start order (bnc#866433)
* Mon Mar 17 2014 werner@suse.de
- Make sure that xinetd service becomes real after network is up (bnc#866433)
* Fri Apr 19 2013 mvyskocil@suse.com
- update to 2.3.15
  * If the address we're binding to is a multicast address, do the multicast join.
  * Merge the Fedora patch to turn off libwrap processing on tcp rpc services.
  Patch xinetd-2.3.12-tcp_rpc.patch.
  * Merge the Fedora patch to add labeled networking.
  Patch xinetd-2.3.14-label.patch r1.4.
  * Merge the Fedora patch to fix getpeercon() for labeled networking in MLS environments.
  Patch xinetd-2.3.14-contextconf.patch r1.1
  * Merge the Fedora patch for int->ssize_t. Patch xinetd-2.3.14-ssize_t.patch r1.1
  * Change compiler flags, -Wconversion generates excessive and unnecessary
  warnings with gcc, particularly all cases of ntohs(uint16_t).
  http://gcc.gnu.org/bugzilla/show_bug.cgi?id=6614 Additionally add -Wno-unused
  to prevent unnecessary warnings regarding unused function parameters when the
  function is a callback conforming to a standard interface.
  * Merge patch from Thomas Swan regarding CVE-2012-0862
- merged the SUSE xinetd.conf with the upstream one
  this changes default target for logging - now the syslog is used
  instead of /var/log/xinetd.log
  * xinetd-config.patch
- logrotate dependency has been dropped and config file is installed
  in /usr/share/doc/packages/xinetd
- drop rc.xinetd and add xinetd.service instead
- add an entry to README.SUSE explaining the systemd socket activation
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sat Sep 15 2012 coolo@suse.com
- fix typo in license string - it's SUSE-xinetd
* Tue May 29 2012 cfarrell@suse.com
- license update: SUSE-xinedt
  Use this license from license.opensuse.org until upstream SPDX accepts
  xinetd into the official list
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Dec 21 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Thu Nov 17 2011 lchiquitto@suse.com
- added xinetd-2.3.14-nodeadlock-revisited.patch: ignore SIGCONT
  and avoid print in signal handler (bnc#726737)
* Wed Apr 21 2010 mseben@novell.com
- added ident-bind.patch : use right size of addresses in bind() call.
  Also use getpeername addresses when connecting to ident service to
  prevent address family mismatch between socket(),
  bind() and connect() calls. (bnc#598305)
* Tue Jan 26 2010 jengelh@medozas.de
- SPARC64 requires large PIE model
* Sun Dec 20 2009 jengelh@medozas.de
- enable parallel build
* Tue Sep 15 2009 mseben@novell.com
- fixed rc.xinetd [bnc#457903]:
  * rc-script start: check if xinetd isn't already running
  * rc-script stop: wait until pid file has disappeared
* Sun Aug 17 2008 aj@suse.de
- Fix init script warnings.
* Fri Sep 14 2007 ro@suse.de
- add a pidfile for xinetd in rc-script (#300526)
* Fri Aug 10 2007 anosek@suse.cz
- added description of the previous patch to README.SuSE
* Tue Aug  7 2007 anosek@suse.cz
- fixed: xinetd does not honour disable line
  [#254613] (honour_disable.patch)
  * As soon as we realize that the service is disabled
    we don't continue parsing its config
* Wed Apr 18 2007 anosek@suse.cz
- improved description for YaST (rc.xinetd)
* Tue Dec 19 2006 prusnak@suse.cz
- added "discard" to service files (and modified ipv6-ipv4-fallback.patch) [#222777]
* Mon Feb  6 2006 mmarek@suse.cz
- fixed logrotate file rotating rotated files
  [#120068, #147899]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov 22 2005 mmarek@suse.cz
- use 'FLAGS = IPv6 IPv4' in included service files
- document the feature in xinetd.conf(5)
* Tue Nov  1 2005 mmarek@suse.de
- updated to version 2.3.14, removed integrated patches:
  * xinetd-2.3.13-gcc4.diff
  * xinetd-2.3.13-ia64.dif
  * xinetd-2.3.13-integer-overflow.diff
  * xinetd-2.3.13-rlimit.diff
- added option to fallback to IPv4 if IPv6 is not available [#127784]
* Mon Oct 10 2005 mmarek@suse.cz
- added upstream patch to fix integer overflow in handling of rlimit_*
  attributes [#120730]
* Tue Oct  4 2005 mmarek@suse.cz
- Fix endless loop in xinetd/util.c [#118878]
* Mon Aug 22 2005 postadal@suse.cz
- added logrotate to Requires
* Tue Aug  9 2005 postadal@suse.cz
- fixed logrotate file [#95214]
* Fri Jun  3 2005 kukuk@suse.de
- Compile with -fpie/-pie
* Fri Apr  1 2005 meissner@suse.de
- lvalue problems fixed
- fixed undefined argv copying behaviour.
* Wed Jan 26 2005 postadal@suse.cz
- added logrotate file [#46353]
* Wed Nov 10 2004 postadal@suse.cz
- added patch to avoid deadlock (LTC#9961, SUSE#43024)
* Thu Apr 22 2004 postadal@suse.cz
- added one second timeout during server startup for deciding if the process
  started without error [#36175]
* Thu Feb 12 2004 postadal@suse.cz
- updated to version 2.3.13
- fixed code that broke strict aliasing
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Thu Aug  7 2003 postadal@suse.cz
- updated to version 2.3.12
- removed obsoleted pacthes (parse-fix, check_from_solar_designer,
  used_valgrind_to_fix, close_listening_descriptor)
- use new stop_on_removal/restart_on_upate macros
* Thu Jun 12 2003 kukuk@suse.de
- Remove /etc/xinetd.d from filelist, is in filesystem
* Mon Jun  2 2003 postadal@suse.cz
- updated to version 2.3.11 (fixed a lot of security bugs)
  * TCPMUX parser updates
  * remove RECORD logging option
  * change Sclose to make sure it always closes the fd
  * added better error handling to filelog.c
  * error messages now go to syslog instead of stderr in strparse.c
  * correct problems with bind specified in the default section
  * correct banner to match man pages
- removed obsoleted flag RECORD from xinetd.conf on line log_on_failure
- removed obsoleted reuse option from rcxinetd script
- added new fix from CVS (check_from_solar_designer, close_listening_descriptor
  and used_valgrind_to_fix)
* Fri Mar  7 2003 postadal@suse.cz
- fixed parsing of bad config file
* Thu Feb 20 2003 postadal@suse.cz
- fixed spec (untar source6)
* Wed Feb 19 2003 postadal@suse.cz
- fixed bug in parsing config file [#22876]
- moved service files to xinetd-service_files.tar.bz2
* Mon Jan 13 2003 jderfina@suse.cz
- upgrade to version 2.3.10.
- Close the service descriptors on fork. This only matters for internal
  forking services, since anything that calls exec() will get those closed
  automagically. This will help reduce the file discriptors used by the daemon
  when using some internal services.
- Fix a numbering bug with xinetd's internal flag representation that was
  manifesting its self as all services being disabled upon recieving a SIGUSR2
  (hard reconfig)
- and many others. See /usr/share/doc/packages/xinetd/CHANGELOG.
* Tue Oct 22 2002 jderfina@suse.cz
- updated to version 2.3.9
- removed template for all services from xinetd.conf. Internal
  services moved as separate files to /etc/xinetd.d/. All external
  services must provide their configuration files to /etc/xinetd.d/.
* Mon Oct  7 2002 jderfina@suse.cz
- reconfig signal for xinetd is SIGHUP now. (#20527)
- added /etc/xinetd.d/ for simpler work with services. (#20534)
* Wed Sep 18 2002 jderfina@suse.cz
- in rc.xinetd moved portmap and autofs from section Required-Start to
  section X-UnitedLinux-Should-Start
* Fri Aug 16 2002 postadal@suse.cz
- added %%insserv_prereq and %%fillup_prereq to PreReq [#18018]
* Fri Aug  9 2002 nadvornik@suse.cz
- updated to 2.3.6
  - merged ipv6 and ipv4 support
  - uses ipv4 by default, ipv6 can be configured per service
- removed obsolete patch xinetd-2.3.2-ipv4.dif
* Sat Jul 27 2002 adrian@suse.de
- do not source rc.config
* Thu Jun 20 2002 postadal@suse.cz
- added definition for an imapd service (bug #16682),
  service imapd is enabled by default
* Tue Mar 12 2002 postadal@suse.cz
- removed obsolete START_INETD variable [#14796]
* Mon Feb 25 2002 postadal@suse.cz
- modified copyright in /etc/xinetd.conf & /etc/init.d/xinetd
* Fri Jan 11 2002 cihlar@suse.cz
- fixed xinetd.conf to disable services with
  specified "id" [#12799]
* Wed Dec 12 2001 cihlar@suse.cz
- removed START_XINETD
* Thu Nov 15 2001 cihlar@suse.cz
- added service nntp/leafnode to xinetd.conf
* Tue Sep 18 2001 cihlar@suse.cz
- updated to version 2.3.3:
  1) Fixed the filelog problem of printing garbage
  2) Fixed the RPC parser to correctly handle RPC version
    ranges again
* Mon Aug 20 2001 cihlar@suse.cz
- updated to version 2.3.2
* Thu Aug 16 2001 cihlar@suse.cz
- updated to version 2.3.1
- removed obsolete audit patch
* Wed Aug  1 2001 cihlar@suse.cz
- updated to version 2.3.0
- added audit patch
- improved patch for kernels without ipv6
  (per_source works now)
- added FAQ
* Fri Jun 22 2001 cihlar@suse.cz
- stop daemon by killproc -QUIT, not -TERM
* Thu Jun 21 2001 cihlar@suse.cz
- fixed security bugs: owerflow, umask and added <=0
  in srtx_* functions - diff of Sebastian Krahmer
* Thu Jun 14 2001 cihlar@suse.cz
- provides inet-daemon [#8675]
* Mon Jun  4 2001 cihlar@suse.cz
- fixed rcxinetd [#8631]
* Mon May 21 2001 cihlar@suse.cz
- fixed cast warnings on ia64
- fixed includes
* Thu Apr 26 2001 draht@suse.de
- added option -reuse to start script to enable a restart of xinetd
  without killing processes.
* Fri Apr 13 2001 cihlar@suse.cz
- fixed init script by new skeleton
* Wed Mar 21 2001 cihlar@suse.cz
- compile with -inet6
- fixed to work with kernels without ipv6 [#6792]
* Thu Feb 15 2001 cihlar@suse.cz
- moved whole files from dif
- use ipop3d instead of popper in /etc/xinetd.conf [#6255]
- use in.ftpd instead of wu.ftpd in /etc/xinetd.conf
- improved startscript
- added suse_update_config
- use RPM_OPT_FLAGS
- removed patch for ipv6 - it works better without it
* Wed Feb 14 2001 cihlar@suse.cz
- applied patch for ipv6
- bzipped sources
* Mon Jan  8 2001 smid@suse.cz
- tcp wrapper support added
* Wed Dec  6 2000 smid@suse.cz
- fixed typo in xinetd.conf [#4485]
* Tue Nov 28 2000 ro@suse.de
- startscript fixed
* Tue Jun 20 2000 smid@suse.cz
- upgrade to 2.1.8.8p3
* Tue May 16 2000 smid@suse.cz
- upgrade to 2.1.8.8p2
- buildroot added
* Wed Mar  1 2000 choeger@suse.de
- new version with ipv6 support and loadavg support
* Tue Jan  4 2000 choeger@suse.de
- disabled ident service per default
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jul  5 1999 choeger@suse.de
- changed to version 2.1.8.6b5, because 2.2.1 is no
  longer maintained
* Thu Dec 10 1998 choeger@suse.de
- added _correct_ symlink to /usr/sbin/rcxinetd :-)
* Thu Dec 10 1998 bs@suse.de
- added symlink /usr/sbin/rxxinetd
* Wed Dec  9 1998 choeger@suse.de
- made init-scripts complete
* Mon Nov 16 1998 ro@suse.de
- added -lcrypt if available
* Thu Nov 12 1998 choeger@suse.de
- security fix for /tmp racecondition
* Wed Feb  4 1998 choeger@suse.de
- v2.2.1 with optimated xinetd.conf
* Fri Oct 31 1997 choeger@suse.de
- new package, 2.2.1
